@@ -46,9 +46,6 @@ extern void srand48(long);
     change srand48 to srand.*/
 #ifdef _MSC_VER
 #define srand48 srand
-#else
-#define min(a,b) ( (a)<(b)?(a):(b) )
-#define max(a,b) ( (a)>(b)?(a):(b) )
 #endif
 
 #define TRUE                             1
@@ -1029,7 +1026,6 @@ void multi_normal_cn_class_merged_marginal( tparm_DS tparm0, tparm_DS tparm1, tp
 void sn_cm_params_influence_fn( model_DS model, tparm_DS tparm, int term_index,int  n_att,
 	float *v, float *class_mean, float *class_sigma, float *class_known_prob,
 	float *global_mean, float *global_sigma, float *global_known_prob);
-priors_DS build_sn_cm_priors( database_DS data_base, att_DS att);
 void single_normal_cm_model_term_builder( model_DS model, term_DS term, int n_term);
 double single_normal_cm_log_likelihood( tparm_DS tparm);
 double single_normal_cm_update_l_approx( tparm_DS tparm);
@@ -1044,7 +1040,7 @@ void single_normal_cm_class_merged_marginal( tparm_DS tparm0,tparm_DS tparm1,tpa
 
 void sn_cn_params_influence_fn( model_DS model, tparm_DS tparm, int term_index, int n_att,
    float *v, float *class_mean,float *class_sigma, float *global_mean, float *global_sigma);
-priors_DS build_sn_cn_priors( att_DS att);
+
 void single_normal_cn_model_term_builder( model_DS model, term_DS term, int n_term);
 double single_normal_cn_log_likelihood( tparm_DS tparm);
 double single_normal_cn_update_l_approx( tparm_DS tparm);
@@ -1354,7 +1350,7 @@ void safe_sprintf( char *str, int str_length, char *caller, char *format, ...);
 /* utils-math.c */
 /* put in separate file 06nov94 wmt */
 
-double log_gamma( double x, int full_precision);
+double log_gamma( double x, int low_precision);
 int atoi_p (char *string_num, int *integer_p_ptr);
 double atof_p (char *string_num, int *float_p_ptr);
 double safe_exp( double x);
