@@ -880,7 +880,7 @@ int *get_source_list( int att_index, att_DS *att_info, int *traced,int n_traced,
 			att_info[att_index]->n_props);
    *n_source = *temp;
    if (source == NULL) {
-      source = (int *) malloc(sizeof(float));
+      source = (int *) malloc(sizeof(int));
       source[0] = att_index;
       return(source);
    }
