@@ -851,18 +851,29 @@ void load_class_DS_s( clsf_DS clsf, int n_classes, FILE *results_file_fp,
   clsf->classes = classes;
 
   for (n_class=0; n_class < n_classes; n_class++) {
+
     classes[n_class] = (class_DS) malloc( sizeof( struct class));
     fread( &header, sizeof( char), header_length, results_file_fp);
     check_load_header( header[0], CLASS_TYPE, caller);
     fread( classes[n_class], sizeof( char), header[1], results_file_fp);
-    classes[n_class]->tparms =
-      (tparm_DS *) malloc( classes[n_class]->num_tparms * sizeof( tparm_DS));
+
+    classes[n_class]->tparms = (tparm_DS *) 
+    malloc( classes[n_class]->num_tparms * sizeof( tparm_DS));
+
     for (n_parm=0; n_parm<classes[n_class]->num_tparms; n_parm++) {
-      classes[n_class]->tparms[n_parm] = (tparm_DS) malloc( sizeof( struct new_term_params));
-      load_tparm_DS( classes[n_class]->tparms[n_parm], n_parm, results_file_fp,
-                    file_ac_version);
+
+      classes[n_class]->tparms[n_parm] = 
+      (tparm_DS) malloc( sizeof( struct new_term_params));
+
+      load_tparm_DS( classes[n_class]->tparms[n_parm], 
+                     n_parm, 
+		     results_file_fp,
+                     file_ac_version);
     }
-    classes[n_class]->wts = (float *) malloc( classes[n_class]->num_wts * sizeof( float));
+
+    classes[n_class]->wts = (float *) 
+    malloc( classes[n_class]->num_wts * sizeof( float));
+
     if (classes[n_class]->wts == NULL) {
       fprintf( stderr,
                "ERROR: load_class_DS_s: out of memory, malloc returned NULL!\n");
