@@ -82,6 +82,7 @@ clsf_DS expand_clsf( clsf_DS clsf, int want_wts_p, int update_wts_p)
 
     check_errors_and_warnings( clsf->database, clsf->models, clsf->num_models);
   }
+
   /* reset class tparms att_indices ptrs to expanded model struct */
   for (i_class=0; i_class<clsf->n_classes; i_class++) {
     n_terms = clsf->classes[i_class]->model->n_terms;
@@ -90,12 +91,14 @@ clsf_DS expand_clsf( clsf_DS clsf, int want_wts_p, int update_wts_p)
       tparm->att_indices = clsf->classes[i_class]->model->terms[i_term]->att_list;
     }
   }
+
   /* If needed, restore the class weights vectors: */
   if ((want_wts_p == TRUE) || (update_wts_p == TRUE))
     expand_clsf_wts( clsf, wts_vector, num_wts);
 
   if ((update_wts_p == TRUE) && (wts_vector == NULL))
     update_wts( clsf, clsf);
+
   return(clsf);
 }
 
@@ -1609,6 +1612,7 @@ void read_class_DS_s( clsf_DS clsf, int n_classes, FILE *results_file_fp,
 
 /* READ_ATT_DS
    17jan95 wmt: new
+   24jan02 wmt: do not assume that translations length < shortstr
 
    read att_DS from results file and allocate storage
    */
@@ -1619,8 +1623,7 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
   float *float_value;
   char *string_value, **token_list = NULL, comment_chars[1], separator_char = ' ';
   char *token_ptr;
-  fxlstr line;
-  shortstr token1, token2, token3;
+  fxlstr line, token1, token2, token3;
   att_DS att;
   real_stats_DS real_stats;
   discrete_stats_DS discrete_stats;
@@ -1648,7 +1651,7 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
   for (i=0; i<expected_token_list_length; i++)
     free( token_list[i]);
   free( token_list);
-
+  
   if (eqstring(att->type, "real")) {
     att->r_statistics = (real_stats_DS) malloc(sizeof(struct real_stats));
     att->d_statistics = NULL;
@@ -1702,9 +1705,9 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
     if (att->n_trans > 0) {
       att->translations = (char **) malloc( att->n_trans * sizeof(char *));
       for (i=0; i < att->n_trans; i++) {
-        att->translations[i] = (char *) malloc( sizeof(shortstr));
         fgets( line, sizeof(line), results_file_fp);
         sscanf( line, "%d %s", &int_token, token2);
+        att->translations[i] = (char *) malloc( strlen( token2) + 1);
         strcpy( att->translations[i], token2);
       }
     }
@@ -1718,7 +1721,7 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
       for (i=0; i < n_props; i++) {
         fgets( line, sizeof(line), results_file_fp);
         sscanf( line, "%s %s %s", token1, token2, token3);
-        token_ptr = (char *) malloc( sizeof( shortstr));
+        token_ptr = (char *) malloc( strlen( token1) + 1);
         strcpy( token_ptr, token1);
         if (eqstring( token2, "int") == TRUE) {
           int_value = (int *) malloc( sizeof( int));
@@ -1731,7 +1734,7 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
           add_to_plist( att, token_ptr, float_value, "flt");
         }
         else if (eqstring( token2, "str") == TRUE) {
-          string_value = (char *) malloc( sizeof( shortstr));
+          string_value = (char *) malloc( strlen( token3) + 1);
           strcpy( string_value, token3);
           add_to_plist( att, token_ptr, string_value, "str");
         }
@@ -1760,7 +1763,7 @@ void read_att_DS( database_DS d_base, int n_att, FILE *results_file_fp, int file
     if (eqstring( token2, "NULL") == TRUE)
       strcpy( att->warnings_and_errors->single_valued_warning, "");
     else 
-      strcpy( att->warnings_and_errors->single_valued_warning, token1);
+      strcpy( att->warnings_and_errors->single_valued_warning, token2);
     /* float *unused_translators_warning; discrete translations not implementated */
     if (att->warnings_and_errors->num_expander_warnings > 0)
       att->warnings_and_errors->model_expander_warnings =
@@ -2034,7 +2037,7 @@ void read_sm_params( struct sm_param *param, int n_atts, FILE *results_file_fp,
   fgets( line, sizeof( line), results_file_fp);
   sscanf( line, "%s", token1);
   if (eqstring( token1, "val_wts") != TRUE) {
-    fprintf( stderr, "read_mn_cn_params expected \"val_wts\", read \"%s\"\n",
+    fprintf( stderr, "read_sm_params expected \"val_wts\", read \"%s\"\n",
             line);
     abort();
   }
@@ -2044,7 +2047,7 @@ void read_sm_params( struct sm_param *param, int n_atts, FILE *results_file_fp,
   fgets( line, sizeof( line), results_file_fp);
   sscanf( line, "%s", token1);
   if (eqstring( token1, "val_probs") != TRUE) {
-    fprintf( stderr, "read_mn_cn_params expected \"val_probs\", read \"%s\"\n",
+    fprintf( stderr, "read_sm_params expected \"val_probs\", read \"%s\"\n",
             line);
     abort();
   }
@@ -2054,7 +2057,7 @@ void read_sm_params( struct sm_param *param, int n_atts, FILE *results_file_fp,
   fgets( line, sizeof( line), results_file_fp);
   sscanf( line, "%s", token1);
   if (eqstring( token1, "val_log_probs") != TRUE) {
-    fprintf( stderr, "read_mn_cn_params expected \"val_log_probs\", read \"%s\"\n",
+    fprintf( stderr, "read_sm_params expected \"val_log_probs\", read \"%s\"\n",
             line);
     abort();
   }
