@@ -457,6 +457,7 @@ void **list_clsf_storage ( clsf_DS clsf, search_DS search, int print_p,
 
 /* FREE_CLSF_DS
    06jan95 wmt: new
+   30jun00 wmt: add pointer checks before freeing
 
    free storage for clsf and its classes and class parameters
    */
@@ -479,8 +480,10 @@ void free_clsf_DS( clsf_DS clsf)
 
   if (clsf->reports != NULL) {
     n_atts = clsf->database->n_atts;
-    free( clsf->reports->class_strength);
-    free( clsf->reports->class_wt_ordering);
+    if (clsf->reports->class_strength != NULL) 
+      free( clsf->reports->class_strength);
+    if (clsf->reports->class_wt_ordering != NULL) 
+      free( clsf->reports->class_wt_ordering);
     if (clsf->reports->att_model_term_types != NULL) {
       for (i_class=0; i_class<n_classes; i_class++) {
         for (i_att=0; i_att<n_atts; i_att++) 
@@ -514,6 +517,7 @@ char *clsf_att_type( clsf_DS clsf, int n_att)
 /* FREE_CLSF_CLASS_SEARCH_STORAGE
    18feb95 wmt: new
    05feb97 wmt: type of ptr variables changed from int * to void **
+   04may01 jcw: Now clears G_model_list and G_m_length after free.
 
    free storage allocated for classification, class, search, and
    search try structures. used for both search and report functions
@@ -552,6 +556,8 @@ void free_clsf_class_search_storage( clsf_DS clsf, search_DS search, int list_gl
     for (i=0; i<G_m_length; i++)
       free_model_DS( G_model_list[i], i);
     free( G_model_list);
+    G_model_list = NULL;
+    G_m_length = 0;
   }
 
   if (search != NULL) {
